<?php

$lan = array(
  'Number of %s rules: %d' => 'N&uacute;mero de %s regras: %d',
  'active' => 'ativa',
  'candidate' => 'candidata',
  'Bounce Regular Expressions' => 'Express&otilde;es regulares para emails de erro',
  'rule' => 'regra',
  'expression' => 'express&atilde;o',
  'action' => 'a&ccedil&atilde;o',
  '#bncs' => '#erros',
  'tag' => 'marcar',
  'order' => 'ordem',
  'del' => 'apagar',
  'with tagged rules: ' => 'com regras marcadas: ',
  'delete' => 'apagar',
  'make inactive' => 'tornar inativa',
  'Save Changes' => 'Salvar Altera&ccedil;&otilde;es',
  'add a new rule' => 'adicionar uma nova regra',
  'Regular Expression' => 'Express&atilde;o Regular',
  'Memo for this rule' => 'Memo para esta regra',
  'Add new Rule' => 'Adicionar nova regra',
  'make active' => 'tornar ativa',
  'No Rules found' => 'Nenhuma Regra foi encontrada',
  'match' => 'verificar',
  'That rule exists already' => 'Essa regra j&aacute; existe',
);

?>
